@@ -1,2 +1,2 @@
 """ A client library for accessing KittyCAD """
-from .client import AuthenticatedClient, Client
+from .client import Client, ClientFromEnv
